# Overview

Companion library for musiccast devices intended for the Home Assistant integration.

This project was generated with [cookiecutter](https://github.com/audreyr/cookiecutter) using [jacebrowning/template-python](https://github.com/jacebrowning/template-python).

[![Unix Build Status](https://img.shields.io/travis/com/vigonotion/template-python-demo.svg?label=unix)](https://travis-ci.com/vigonotion/template-python-demo)
[![Windows Build Status](https://img.shields.io/appveyor/ci/vigonotion/template-python-demo.svg?label=windows)](https://ci.appveyor.com/project/vigonotion/template-python-demo)
[![Coverage Status](https://img.shields.io/coveralls/vigonotion/template-python-demo.svg)](https://coveralls.io/r/vigonotion/template-python-demo)
[![Scrutinizer Code Quality](https://img.shields.io/scrutinizer/g/vigonotion/template-python-demo.svg)](https://scrutinizer-ci.com/g/vigonotion/template-python-demo)
[![PyPI Version](https://img.shields.io/pypi/v/aiomusiccast.svg)](https://pypi.org/project/aiomusiccast)
[![PyPI License](https://img.shields.io/pypi/l/aiomusiccast.svg)](https://pypi.org/project/aiomusiccast)

# Setup

## Requirements

* Python 3.8+

## Installation

Install it directly into an activated virtual environment:

```text
$ pip install aiomusiccast
```

or add it to your [Poetry](https://poetry.eustace.io/) project:

```text
$ poetry add aiomusiccast
```

# Usage

After installation, the package can imported:

```text
$ python
>>> import aiomusiccast
>>> aiomusiccast.__version__
```
